"""Creates a queue, iterates through docs and waits when queue is empty."""

__version__ = '1.0.2'
__url__ = 'https://github.com/discogs/pymongo-job-queue'
__author__ = 'Andy Craze'
__email__ = 'acraze@discogsinc.com'

from jobqueue import JobQueue
